@@ -30,7 +30,7 @@
 #'
 #' * style character; can be null or "nejm" for different table styling
 #'
-#' * pct_width numeric; a scaling to be applied to the entire table
+#' * rel_size numeric; a scaling to be applied to the entire table, e.g. rel_size=-2
 #'
 #' * placement character; placement directive, defaults to "H"
 #'
@@ -171,7 +171,6 @@ latex.tangram <- function(object,
   na.blank     <- NULL # These lines are to pass CRAN checks, because it can't fathom assign
   cgroup.just  <- NULL
   arraystretch <- NULL
-  pct_width    <- NULL
   relsize      <- NULL
   placement    <- NULL
   style        <- NULL
@@ -181,7 +180,6 @@ latex.tangram <- function(object,
     na.blank=TRUE,
     cgroup.just=NULL,
     arraystretch=1.2,
-    pct_width=1.0,
     relsize=0,
     placement="H",
     style="hmisc",
@@ -201,7 +199,7 @@ latex.tangram <- function(object,
           )
   }
 
-  if(pct_width != 1.0) stop("tangram now uses longtable and width scaling is no longer supported try relsize=-2")
+  if("pct_width" %in% names(call.args)) stop("tangram now uses longtable and width scaling is no longer supported try relsize=-2")
 
   # Find footnote
   footnote <- attr(object, "footnote")
@@ -217,6 +215,17 @@ latex.tangram <- function(object,
     result <- paste(result,
                     "\\documentclass{report}",
                     "\\usepackage{geometry}",
+                    "\\usepackage[LGR,T1]{fontenc}",
+                    "\\usepackage[utf8]{inputenc}",
+                    "\\usepackage{textgreek}",
+                    "\\usepackage{float}",
+                    "\\usepackage[x11names,dvipsnames,table]{xcolor}",
+                    "\\usepackage{boldline}",
+                    "\\usepackage{multirow}",
+                    "\\usepackage{colortbl}",
+                    "\\usepackage{hhline}",
+                    "\\usepackage{longtable}",
+                    "\\usepackage{relsize}",
                     "\\begin{document}",
                     sep="\n")
   }
@@ -234,10 +243,6 @@ latex.tangram <- function(object,
   if(relsize != 0) result <- paste0(result, "{\\relsize{",relsize,"}\n")
   if(style %in% c("nejm", "lancet")) result <- paste0(result, "{\\fontfamily{cmss}\\selectfont\n")
 
-
-  #if(pct_width != 1.0) result <- paste0(result, "\\scalebox{", pct_width, "}{\n")
-
-
   nrows <- rows(object)
   ncols <- cols(object)
   text  <- matrix(data=rep("", nrows*ncols), nrow=nrows, ncol=ncols)
@@ -327,10 +332,8 @@ latex.tangram <- function(object,
 
   result <- paste0(result, "\\end{longtable}\n")
 
-  #if(pct_width != 1.0) result <- paste0(result, "}\n")
   if(relsize != 0) result <- paste0(result, "}\n")
 
-
   if(style %in% c("nejm","lancet")) result <- paste0(result, "}\n")
 
   if(!fragment)
@@ -350,3 +353,28 @@ latex.tangram <- function(object,
 
   result
 }
+
+#' Return a LaTeX template that works with tangram
+#'
+#' Pandoc in the current version of RStudio does not allow for setting
+#' package options to xcolor and this has made it incompatible with
+#' the LaTeX generated by this package. This provides a known
+#' working template.
+#'
+#' An example header would look like the following:
+#'
+#' ---
+#' title: "A Document Full of Beautiful Tables"
+#'   output:
+#'     pdf_document:
+#'     "`r tangram::latex_template()`"
+#' ---
+#'
+#' @return filename of LaTeX template
+#' @export
+#' @example tangram::latex_template()
+#'
+latex_template <- function()
+{
+  file.path(system.file(package="tangram"), "extdata", "tex", "tangram.template")
+}
